# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .pay_i_common_models_budget_management_cost_details_base import (
    PayICommonModelsBudgetManagementCostDetailsBase as PayICommonModelsBudgetManagementCostDetailsBase,
)
